
# coding: utf-8



import pymongo
from pymongo import MongoClient
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
import os, sys
import scipy
import datetime
import math
import IPython.display

#Loading Data Collections
client = MongoClient()
db = client['rfid_data']


coll26 = db["links_26"]
coll27 = db["links_27"]
coll28 = db["links_28"]
coll29= db["links_29"]
coll30= db["links_30"]


#sculptures identifiers

sculpture1 = ["928", "976", "761", "457", "354", "946", "455", "476"]
sculpture2 = ["462", "925", "916", "345", "411", "412", "493", "419"]
sculpture3 = ["559", "992", "999", "348", "956", "463", "417", "561"]
all_activities=sculpture1+sculpture2+sculpture3+["1469","856","983","982","780","1823","585","534"]



#generation of contacts with LEGO sculptures

sculpt_contacts = {}
users = {}
sidx_to_idx = {}
users_contacts = {}

day=30

for day in [27,29,30]:
    t0 = datetime.datetime(2016,10,day, 9,0,0)

    users[day] = {}
    sculpt_contacts[day]  = {"sculpt1":{},"sculpt2":{}, "sculpt3":{}}
    users_contacts[day] = {}

    sidx_to_idx[day] = {}

    for record in db["links_"+str(day)].find():
        mongo_id = record["_id"]
        rfid = record["rfid"]
        t_start = record["t_start"]
        t_stop = record["t_stop"]
        age = record["age"]
        string_id = record["string_id"]
        users[day][string_id] = {"rfid":rfid, "t_start":t_start, "t_stop":t_stop, "age":age, "string_id":record["string_id"]}

        sidx_to_idx[day][record["string_id"]] = record["_id"]

        sculpt_contacts[day]["sculpt1"][string_id] = record["aggr_contacts_sculptures"]["sculpt1"]
        sculpt_contacts[day]["sculpt2"][string_id] = record["aggr_contacts_sculptures"]["sculpt2"]
        sculpt_contacts[day]["sculpt3"][string_id] = record["aggr_contacts_sculptures"]["sculpt3"]



#calculation of interaction times
user_interaction_times = {}
for day in [27,29,30]:
    user_interaction_times[day] = {}
    for string_id in users[day]:
        user_interaction_times[day][string_id] = {sculpt:0.0 for sculpt in ["sculpt1","sculpt2","sculpt3"]}
        for sculpt in ["sculpt1","sculpt2","sculpt3"]:
            c_list = [c[1]-c[0] for c in sculpt_contacts[day][sculpt][string_id]]
            if c_list==[]: continue
            user_interaction_times[day][string_id][sculpt] = np.sum(c_list)



#calculation of interaction times entropies
entropies = {}
for day in [27,29,30]:
    entropies[day] = {}
    for string_id in users[day]:
        
        times = user_interaction_times[day][string_id].values()
        if np.sum(times)==0: entropies[day][string_id] =  0
        else: entropies[day][string_id] = scipy.stats.entropy(times)/np.log(3)



#plotting results



sns.set_style("whitegrid")
sns.set_context("paper", font_scale=2.5, rc={"lines.linewidth": 2.5})

plt.figure(figsize=(8, 6))

all_entropies = []
for v in [27,29,30]: all_entropies+=entropies[day].values()
plt.hist(all_entropies, bins=np.arange(0,1.1,0.1),normed=True)


plt.xlabel("$h$", fontsize=25)
plt.ylabel("$P(h)$", fontsize=25)

plt.tight_layout()
plt.savefig("./entropy.png", dpi=300, transparent=False, bbounding_box="tight")





