
# coding: utf-8



import pymongo
from pymongo import MongoClient
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
import os, sys
import scipy
from datetime import datetime
import math
import IPython.display

def avg_vol_func(x,v_hole):
    if x==[]: return v_hole
    avg = scipy.average(x)
    if avg<0: return 0.0
    return avg



#Loading Data Collections
client = MongoClient()
db = client['rfid_data']


coll26 = db["links_26"]
coll27 = db["links_27"]
coll28 = db["links_28"]
coll29= db["links_29"]
coll30= db["links_30"]


#sculptures identifiers

sculpture1 = ["928", "976", "761", "457", "354", "946", "455", "476"]
sculpture2 = ["462", "925", "916", "345", "411", "412", "493", "419"]
sculpture3 = ["559", "992", "999", "348", "956", "463", "417", "561"]
all_activities=sculpture1+sculpture2+sculpture3+["1469","856","983","982","780","1823","585","534"]




#compute volumes time series
day=29 #CHOSE THE DAY (27,29,30)

#

times1 = []
volumes1 = []
t0 = datetime(2016,10,day,9,0,0)

for record in db["sculpt_volumes_time_series_"+str(day)].find({"sculpture":1}).sort([("t", pymongo.ASCENDING)]):
    t = record["t"]
    vol = record["volume"]
    times1.append((t-t0).total_seconds())
    volumes1.append(vol)
    

times2 = []
volumes2 = []
t0 = datetime(2016,10,day,9,0,0)

for record in db["sculpt_volumes_time_series_"+str(day)].find({"sculpture":2}).sort([("t", pymongo.ASCENDING)]):
    t = record["t"]
    vol = record["volume"]
    times2.append((t-t0).total_seconds())
    volumes2.append(vol)
    
    
times3 = []
volumes3 = []
t0 = datetime(2016,10,day,9,0,0)

for record in db["sculpt_volumes_time_series_"+str(day)].find({"sculpture":3}).sort([("t", pymongo.ASCENDING)]):
    t = record["t"]
    vol = record["volume"]
    times3.append((t-t0).total_seconds())
    volumes3.append(vol)



#aggregation every 20 secs


l_vol1 = [[] for index in range(int(3600*12/20))]

for t, vol in zip(times1,volumes1):
    index = int(t/20)
    l_vol1[index].append(vol)


min_v = max(min(volumes1),0.0)
min_v = 0
aggr_vol1 = []
for i in range(len(l_vol1)):
    if i < len(l_vol1)/2: v_hole = min_v
    else: v_hole = aggr_vol1[-1]
    
    aggr_vol1.append(avg_vol_func(l_vol1[i], v_hole))
    

    
l_vol2 = [[] for index in range(int(3600*12/20))]

for t, vol in zip(times2,volumes2):
    index = int(t/20)
    l_vol2[index].append(vol)


min_v = max(min(volumes2),0.0)
min_v = 0
aggr_vol2 = []
for i in range(len(l_vol2)):
    if i < len(l_vol2)/2: v_hole = min_v
    else: v_hole = aggr_vol2[-1]
    
    aggr_vol2.append(avg_vol_func(l_vol2[i], v_hole))
    
    
l_vol3 = [[] for index in range(int(3600*12/20))]

for t, vol in zip(times3,volumes3):
    index = int(t/20)
    l_vol3[index].append(vol)


min_v = max(min(volumes3),0.0)
min_v = 0
aggr_vol3 = []
for i in range(len(l_vol3)):
    if i < len(l_vol3)/2: v_hole = min_v
    else: v_hole = aggr_vol3[-1]
    
    aggr_vol3.append(avg_vol_func(l_vol3[i], v_hole))


aggr_vol1  = aggr_vol1[:1800]
if day==30: aggr_vol2  = aggr_vol2[:900]
else: aggr_vol2  = aggr_vol2[:]
aggr_vol3  = aggr_vol3[:1800]


current_palette =sns.color_palette()



#plot

sns.set_style("white")
sns.set_context("paper", font_scale=1.7)


fig, (ax1, ax2, ax3) = plt.subplots(1,3, figsize=(25,5))

ax1.plot(aggr_vol1, label="sculpture1", linewidth=3, color=current_palette[0])
ax2.plot(aggr_vol2, label="sculpture2", linewidth=3, color=current_palette[1])
ax3.plot(aggr_vol3, label="sculpture3", linewidth=3, color=current_palette[2])


ax1.set_ylabel("$n_{bricks}$", fontsize=30)
ax2.set_ylabel("$n_{bricks}$", fontsize=30)
ax3.set_ylabel("$n_{bricks}$", fontsize=30)

ax1.set_xlabel("$t$", fontsize=30)
ax2.set_xlabel("$t$", fontsize=30)
ax3.set_xlabel("$t$", fontsize=30)


ax1.set_xlim(xmax=1700)
ax2.set_xlim(xmax=1700)
ax3.set_xlim(xmax=1700)

ax1.legend(loc="upper left")
ax2.legend(loc="upper left")
ax3.legend(loc="upper left")

plt.tight_layout()
plt.savefig("volumes_in_time_"+str(day)+".png", dpi=300, transparent=False, bbounding_box="tight")



import pickle
data = {"vol1": aggr_vol1, "vol2":aggr_vol2, "vol3":aggr_vol3}
pickle.dump(file=open("./volumes_time_series"+str(day)+".pickle", "wb"),obj=data)



